@@ -52,7 +52,7 @@
   (defun-maybe Meadow-version ()))
 
 (product-provide 'weather-version
-  (product-define "Weather" nil '(0 27)))
+  (product-define "Weather" nil '(0 28)))
 
 (defvar weather-insert-user-agent nil)
 
@@ -318,8 +318,9 @@ If OFFLINE is nil, don't fetch weather, only use cache. "
 		       (null weather-where))
 		   (list (read-from-minibuffer "Where: "
 					       weather-where))))
-  (let ((ret-val
-	 (if (and where (listp where))
+  (let* ((where (or where weather-where))
+	 (ret-val
+	  (if (and where (listp where))
 	     (weather-from-http-list where offline)
 	   (weather-from-http-subr where offline))))
     (if (and (null ret-val)
@@ -331,8 +332,7 @@ If OFFLINE is nil, don't fetch weather, only use cache. "
       ret-val)))
 
 (defun weather-from-http-subr (where &optional offline)
-  (let ((where (or where weather-where))
-	ret-val)
+  (let (ret-val)
     (setq ret-val
 	  (or (weather-read-cache where)
 	      (and (null offline)
